@@ -30,8 +30,13 @@ from dask.utils import natural_sort_key, parse_bytes
 from fsspec.core import get_fs_token_paths
 from fsspec.utils import stringify_path
 
-import merlin.core.dispatch as dispatch
-from merlin.core.dispatch import convert_data, hex_to_int, is_dataframe_object
+from merlin.core.dispatch import (
+    convert_data,
+    hex_to_int,
+    is_dataframe_object,
+    is_list_dtype,
+    list_val_dtype,
+)
 from merlin.core.utils import device_mem_size, global_dask_client, set_client_deprecated
 from merlin.io.csv import CSVDatasetEngine
 from merlin.io.dask import _ddf_to_dataset, _simple_shuffle
@@ -203,11 +208,8 @@ class Dataset:
         This overrides the derived schema behavior.
     **kwargs :
         Key-word arguments to pass through to Dask.dataframe IO function.
-        For the Parquet engine(s), notable arguments include `filters`,
-        `aggregate_files`, and `gather_statistics`. Note that users who
-        do not need to know the number of rows in their dataset (and do
-        not plan to preserve a file-partition mapping) may wish to use
-        `gather_statistics=False` for better client-side performance.
+        For the Parquet engine(s), notable arguments include `filters`
+        and `aggregate_files` (the latter is experimental).
     """
 
     def __init__(
@@ -541,7 +543,8 @@ class Dataset:
             .repartition(
                 npartitions=npartitions,
                 partition_size=partition_size,
-            )
+            ),
+            schema=self.schema,
         )
 
     @classmethod
@@ -850,6 +853,7 @@ class Dataset:
                 output_files = [f"part_{i}" + suffix for i in range(output_files)]
             if isinstance(output_files, list):
                 new = {}
+                file_count = 0
                 split = math.ceil(ddf.npartitions / len(output_files))
                 for i in range(0, len(output_files), files_per_task):
                     fns = output_files[i : i + files_per_task]
@@ -857,10 +861,11 @@ class Dataset:
                     stop = min(start + split * len(fns), ddf.npartitions)
                     if start < stop:
                         new[tuple(fns)] = np.arange(start, stop)
+                        file_count += len(fns)
                 # let user know they will not have expected number of output files.
-                if len(new.keys()) < len(output_files):
+                if file_count < len(output_files):
                     warnings.warn(
-                        f"Only created {len(new.keys())} files did not have enough "
+                        f"Only creating {file_count} files. Did not have enough "
                         f"partitions to create {len(output_files)} files."
                     )
                 output_files = new
@@ -1153,8 +1158,8 @@ class Dataset:
             _real_meta = self._real_meta[n]
             annotated = {
                 col: {
-                    "dtype": dispatch.list_val_dtype(_real_meta[col]) or _real_meta[col].dtype,
-                    "is_list": dispatch.is_list_dtype(_real_meta[col]),
+                    "dtype": list_val_dtype(_real_meta[col]) or _real_meta[col].dtype,
+                    "is_list": is_list_dtype(_real_meta[col]),
                 }
                 for col in _real_meta.columns
             }
